
declare
v_grid_name varchar2(6);
v_grid_id number(14);
v_grid_desc varchar2(40);
v_field_id number(14);
v_field_id_list VARCHAR2(1000);
v_grid_key_fields VARCHAR2(200);
v_dataspy_id number(14);
v_bot_number number(14);
v_field_source_name varchar2(100);
v_field_tag_name varchar2(100);
v_language VARCHAR2(2);
r5boilertexts_exists integer;
r5grid_exists integer;
r5functions_exists integer;
sequence_check varchar2(3);

begin

-------------------------------------------------------------------------------
-- Set custom grid name
-------------------------------------------------------------------------------

v_grid_name := 'AUI006'; 
v_language := '&1';

-------------------------------------------------------------------------------
-- Cleanup existing r5boilertexts
-------------------------------------------------------------------------------

select count(*) into r5boilertexts_exists
from r5boilertexts
where BOT_FUNCTION = v_grid_name
and rownum = 1;

IF r5boilertexts_exists = 1 THEN
	DELETE FROM r5boilertexts where BOT_FUNCTION = v_grid_name;
END IF;

-------------------------------------------------------------------------------
-- Cleanup existing r5grid and related data
-------------------------------------------------------------------------------

select count(*) into r5grid_exists
from r5grid
where GRD_GRIDNAME = v_grid_name
and rownum = 1;

IF r5grid_exists = 1 THEN
	DELETE FROM r5queryfield where DQF_DDSPYID in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
	DELETE FROM r5usegridsysdefault where usd_dataspyid in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
    DELETE FROM R5dddataspy WHERE DDS_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridfield where GFD_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridparam where GDP_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5grid WHERE GRD_GRIDNAME = v_grid_name;
END IF;


-------------------------------------------------------------------------------
-- Cleanup existing r5functions
-------------------------------------------------------------------------------

select count(*) into r5functions_exists
from r5functions
where FUN_CODE = v_grid_name
and rownum = 1;

IF r5functions_exists = 1 THEN
  DELETE FROM R5EXTMENULANG WHERE EML_EXTMENU IN (SELECT EMN_CODE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name);
  DELETE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name;
  DELETE FROM r5functions where FUN_CODE = v_grid_name;
END IF;


-------------------------------------------------------------------------------
--Insert r5functions
-------------------------------------------------------------------------------
INSERT INTO R5FUNCTIONS (FUN_CODE,FUN_DESC,FUN_CLASS,FUN_SUBTYPE,FUN_FILE,FUN_PUBLIC,FUN_SELECT,FUN_BACKGROUND,FUN_APPLICATION,FUN_DIRSEL,FUN_SYSTEM,FUN_DISPLAYAP,FUN_DISPLAYFT,FUN_POPUPAP,FUN_POPUPFT,FUN_DESCCHANGED,FUN_CLASS_ORG,FUN_RS,FUN_LST,FUN_HDR,FUN_EWSREPORT,FUN_PRDDATASRC,FUN_EWSURLNEW,FUN_REPDISABLED,FUN_ADVREPT,FUN_MEKEY,FUN_EWSBTN)
 VALUES (v_grid_name,'PO Receipt processed lines (AM)','WEBD','M','R5MENU','-','?','-','BSUGRD','-','+','-','+','-','-','-','*','-','+','-','-','-','-','-','-','YN','-');

-------------------------------------------------------------------------------
-- Insert r5grid
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_grid_id, 'GRD', '1', sequence_check);
INSERT INTO R5GRID (GRD_DESC,GRD_GRIDID,GRD_BASEQUERY,GRD_GRIDNAME,GRD_BOTFUNCTION,GRD_PORTLETFLAG,GRD_TAB,GRD_GRIDTYPE,GRD_OPTIMIZERON,GRD_DISTINCT,GRD_COMPLEX,GRD_ACTIVE,GRD_NOSCREENDESIGNER)
 VALUES ('PO Receipt processed lines (AM)',v_grid_id,'FROM r5docklines d,r5dockreceipts r,r5orderlines o,r5parts p,r5partmfgs m,r5events e,r5activities a, r5addetails c WHERE d.dkl_linerstatus = ''A''
AND d.dkl_dckcode = r.dck_code
AND        o.orl_order (+) = d.dkl_order
AND        o.orl_ordline (+) = d.dkl_ordline
AND        o.orl_order_org (+) = d.dkl_order_org
AND        d.dkl_part = p.par_code
AND        d.dkl_part_org = p.par_org
AND        m.mfp_part (+) = p.par_code 
AND        m.mfp_part_org (+) = p.par_org
AND        m.mfp_PRIMARY (+) = ''+''
AND        o.orl_event = e.evt_code (+)
AND		   o.orl_event = a.act_event (+)
AND		   o.orl_act = a.act_act (+)
AND        c.ADD_ENTITY (+) = ''PORL'' 
AND        c.ADD_LINE (+) = ''10'' 
AND        c.ADD_CODE (+)  = dkl_order||''#''||dkl_order_org||''#''||dkl_line
',v_grid_name,v_grid_name,'-','+',2,'+','-','-','+','-');

-------------------------------------------------------------------------------
-- Insert r5dddataspy
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_dataspy_id, 'DDS', '1', sequence_check);
INSERT INTO R5DDDATASPY (DDS_DDSPYNAME,DDS_DDSPYID,DDS_SCOPE,DDS_ORGANIZATION,DDS_CREATEDSTAMP,DDS_FILTERSTRXML,DDS_SORTSTRXML,DDS_OWNER,DDS_GRIDID,DDS_TYPE,DDS_DEFAULTFLAG,DDS_CLIENTROWS,DDS_BOTNAME,DDS_SECURITYDATASPY,DDS_MEKEY)
 VALUES ('All Records',v_dataspy_id,'-','*',sysdate,'<FILTERABLE />','<SORTABLE />','R5',v_grid_id,'SD','+',30,'DSNAME','-','YY');

-------------------------------------------------------------------------------
-- Insert the three base r5boilertexts
-- Note: You must also insert a r5boilertext record for each "grid field" (see below)
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,1,100,0,0,v_language,'List View','TB','1','LST','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,2,100,0,0,v_language,'PO Receipt processed lines (AM)','F','1','UDG_HDRLABEL','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,3,100,0,0,v_language,'All Records','F','1','DSNAME','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,4,100,0,0,v_language,'dkl_dckcode','F','1','dkl_dckcode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,5,100,0,0,v_language,'dkl_line','F','1','dkl_line','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,6,100,0,0,v_language,'dkl_part','F','1','dkl_part','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,8,100,0,0,v_language,'dkl_part_org','F','1','dkl_part_org','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,10,100,0,0,v_language,'orl_type','F','1','orl_type','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,11,100,0,0,v_language,'dkl_countqty','F','1','dkl_countqty','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,12,100,0,0,v_language,'dkl_bin','F','1','dkl_bin','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,15,100,0,0,v_language,'dkl_obtype','F','1','dkl_obtype','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,18,100,0,0,v_language,'dkl_object_org','F','1','dkl_object_org','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,23,100,0,0,v_language,'dkl_order','F','1','dkl_order','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,24,100,0,0,v_language,'dkl_order_org','F','1','dkl_order_org','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,50,100,0,0,v_language,'dkl_print','F','1','dkl_print','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,51,100,0,0,v_language,'dkl_recvqty','F','1','dkl_recvqty','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,54,100,0,0,v_language,'partdescription','F','1','partdescription','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,55,100,0,0,v_language,'typedescription','F','1','typedescription','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,56,100,0,0,v_language,'dkl_ordline','F','1','purchaseorderline','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,57,100,0,0,v_language,'dkl_linestatus','F','1','receiptlinestatus','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,58,100,0,0,v_language,'dkl_updatecount','F','1','recordid','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,59,100,0,0,v_language,'assettypedescription','F','1','assettypedescription','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,60,100,0,0,v_language,'par_uom','F','1','uom','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,61,100,0,0,v_language,'ORL_RECVQTY','F','1','orderreceivedqty','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,62,100,0,0,v_language,'ORL_ORDQTY','F','1','requestedqty','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,63,100,0,0,v_language,'MFP_MANUFACTPART','F','1','manufactpart','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,64,100,0,0,v_language,'workordercode','F','1','workordercode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,65,100,0,0,v_language,'costcenter','F','1','costcenter','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,66,100,0,0,v_language,'deladdress','F','1','deladdress','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,67,100,0,0,v_language,'attentionto','F','1','attentionto','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,68,100,0,0,v_language,'workorderobject','F','1','workorderobject','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,69,100,0,0,v_language,'workorderproject','F','1','workorderproject','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,70,100,0,0,v_language,'activitypeid','F','1','activitypeid','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,71,100,0,0,v_language,'linedesc','F','1','linedesc','10000',sysdate,'-');
 
-------------------------------------------------------------------------------
-- Copy the R5BOILERTEXTS for each of the languages in the R5LANGINST
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED)
SELECT BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,LIN_CODE,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED
FROM R5BOILERTEXTS, R5LANGINST
WHERE
BOT_LANG = v_language AND BOT_FUNCTION = v_grid_name AND lin_code <> v_language;

-------------------------------------------------------------------------------
-- Insert r5ddfield, r5gridfield, r5queryfield for each grid field
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_dckcode','VARCHAR','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,4,'TEXT','receiptcode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',1,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  v_grid_key_fields || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_line','NUMBER','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,5,'TEXT','linenumber','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',2,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_part','VARCHAR','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,6,'TEXT','partcode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',3,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_part_org','VARCHAR','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,8,'TEXT','partorganization','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',4,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'o.orl_type','VARCHAR','R5ORDERLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,10,'TEXT','typecode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',5,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_countqty','DECIMAL','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,11,'TEXT','receiptquantity','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',6,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_bin','VARCHAR','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,12,'TEXT','bincode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',7,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_obtype','VARCHAR','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,15,'TEXT','assettype','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',8,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_object_org','VARCHAR','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,18,'TEXT','assetorganization','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',9,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_order','VARCHAR','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,23,'TEXT','purchaseordercode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',10,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_order_org','VARCHAR','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,24,'TEXT','purchaseorderorganization','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',11,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_print','NUMBER','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,50,'TEXT','printquantity','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',12,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_recvqty','DECIMAL','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,51,'TEXT','receivedquantity','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',13,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'r5o7.o7get_desc(:parameter.language,''PART'', dkl_part||''#''||dkl_part_org,'''', '''')','VARCHAR','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,54,'TEXT','partdescription','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',14,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'r5o7.o7get_desc(''EN'',''UCOD'', o.orl_type,''PLTP'', '''')','VARCHAR','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,55,'TEXT','typedescription','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',15,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_ordline','NUMBER','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,56,'TEXT','purchaseorderline','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',16,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.dkl_linestatus','VARCHAR','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,57,'TEXT','receiptlinestatus','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',17,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'d.DKL_UPDATECOUNT','NUMBER','R5DOCKLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,58,'TEXT','recordid','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',18,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'r5o7.o7get_desc(''EN'',''UCOD'', d.dkl_obtype,''OBTP'', '''')','VARCHAR','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,59,'TEXT','assettypedescription','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',19,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'p.par_uom','MIXVARCHAR','R5PARTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,60,'TEXT','uom','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',20,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'o.ORL_RECVQTY','DECIMAL','R5ORDERLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,61,'TEXT','orderreceivedqty','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',21,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'o.ORL_ORDQTY','DECIMAL','R5ORDERLINES');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,62,'TEXT','requestedqty','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',22,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'m.mfp_manufactpart','MIXVARCHAR','R5PARTMFGS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,63,'TEXT','manufactpart','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',23,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'o.orl_event','VARCHAR','r5orderlines');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,64,'TEXT','workordercode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',24,'LIST');
 
 r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_mrc','VARCHAR','r5events');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,65,'TEXT','costcenter','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',25,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'o.orl_deladdress','VARCHAR','r5orderlines');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,66,'TEXT','deladdress','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',26,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'o.orl_attentionto','VARCHAR','r5orderlines');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,67,'TEXT','attentionto','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',27,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_object','VARCHAR','r5events');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,68,'TEXT','workorderobject','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',28,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_project','VARCHAR','r5events');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,69,'TEXT','workorderproject','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',29,'LIST');
 
r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'a.act_udfchar07','VARCHAR','r5activities');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,70,'TEXT','activitypeid','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',30,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_TABLENAME)
 VALUES (v_field_id,'dbms_lob.substr(R5REP.TRIMHTML(c.ADD_CODE, c.ADD_RENTITY, c.ADD_TYPE, c.ADD_LANG, c.add_line), 80, 1)','VARCHAR','r5activities');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,71,'TEXT','linedesc','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',31,'LIST');
 
-------------------------------------------------------------------------------
-- Insert r5gridparam
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- Setup field keys on r5grid
-------------------------------------------------------------------------------

update r5grid set 
grd_keyfields = v_grid_key_fields, 
grd_filterablelist = v_field_id_list,
grd_sortablelist = v_field_id_list,
grd_displayablelist = v_field_id_list
where grd_gridid = v_grid_id;

commit;

end;

/
